# two_link_sensor.py
#
# Sample Webots controller file for driving the two-link arm
# with two driven joints.  This example uses the end sensor
# to search for objects in the vicinity.

# No copyright, 2020-2021, Garth Zeglin.  This file is
# explicitly placed in the public domain.

import math
import time
from controller import Robot
print("loading duo_sensor_dance.py...")

# Import the Webots simulator API.

# Import the standard Python math library.

# Define the time step in milliseconds between controller updates.
EVENT_LOOP_DT = 200

#

# Request a proxy object representing the robot to control.
robot = Robot()
robot_name = robot.getName()
print("%s: controller connected." % (robot_name))

# Fetch handle for the 'base' and 'elbow' joint motors.
motor1 = robot.getDevice('motor1')
motor2 = robot.getDevice('motor2')

# Adjust the low-level controller gains.
print("%s: setting PID gains." % (robot_name))
motor1.setControlPID(2.0, 0.0, 0.1)
motor2.setControlPID(2.0, 0.0, 0.1)

# Fetch handles for the joint sensors.
joint1 = robot.getDevice('joint1')
joint2 = robot.getDevice('joint2')

# Specify the sampling rate for the joint sensors.
joint1.enable(EVENT_LOOP_DT)
joint2.enable(EVENT_LOOP_DT)

# Connect to the end sensor.
sensor_left = robot.getDevice("leftArmSensor")
sensor_right = robot.getDevice("rightArmSensor")

sensor_right.enable(EVENT_LOOP_DT)  # set sampling period in milliseconds
sensor_left.enable(EVENT_LOOP_DT)


# Run loop to execute a periodic script until the simulation quits.
# If the controller returns -1, the simulator is quitting.

# TODO: rotote using sine wave

oscillate = True
position = 0
ocsillatate_to_fro = math.pi/2
wait_iteration = 0
while robot.step(EVENT_LOOP_DT) != -1:
    # Read simulator clock time.
    t = robot.getTime()

    # We are giving this a periodicity of 10 seconds
    if oscillate:
        t_period = 10
        position = ocsillatate_to_fro * math.sin(t * (2*math.pi)/t_period)
        motor2.setPosition(position)

    distance_r = sensor_right.getValue()
    distance_l = sensor_left.getValue()

    # TODO: get current poisiton and try to move there

    if distance_r < 0.5:
        # print("Touched right")
        position = motor2.getTargetPosition()
        motor2.setPosition(-position)
        oscillate = False
    if distance_l < 0.5:
        # print("touched left")
        position = motor2.getTargetPosition()
        motor2.setPosition(-position)
        oscillate = False

    if ((distance_r > 0.8) or (distance_l > 0.8)):
        # Let us wait 5 iterations
        wait_iteration = wait_iteration+1
        if wait_iteration > 4:
            oscillate = True
            wait_iteration = 0

    else:
        print(
            f"We are at out destination. Left is {distance_l} and right is {distance_r}")
        oscillate_to_fro = motor2.getTargetPosition()
        print(f"we will oscilalte to and from {oscillate_to_fro}")
        motor2.setVelocity(0)
        time.sleep(3)
        # Wait for 3 seconds
        oscillate = True
        motor2.setVelocity(5)
